import requests
from requests.auth import HTTPBasicAuth
import json

class oe_api():

    def __init__(self, api_key, mpan, serial_number, account_number):
        
        api_key = api_key
        self.mpan = mpan
        self.serial_number = serial_number
        self.account_number = account_number

        self.s = requests.session()
        self.s.auth = (api_key, "")

        self.base = "https://api.octopus.energy/v1"
    
    def _get(self, url):
        
        response = self.s.request(method="GET", url=url)

        parsed = response.json()

        return( parsed )


    def GetAccountDetails(self):

        response = self._get(f"https://api.octopus.energy/v1/accounts/{self.account_number}")

        return(response)

    def GetConsumption(self):

        self._get(f"https://api.octopus.energy/v1/electricity-meter-points/{self.mpan}/meters/{self.serial_number}/consumption/?page_size=100&period_from=2021-02-15T00:00Z&period_to=2021-03-01T01:29Z&order_by=period")

    def GetProduct(self):

        self._get(f"https://api.octopus.energy/v1/products/?brand=OCTOPUS_ENERGY")

    def convert_datetime_to_tz(cls, time):
        
        format_tz='%Y-%m-%dT%H:%M:%S%z'

        return(time.strftime(format_tz))
    
    def get_consumption(self, start, end):
        
        start=self.convert_datetime_to_tz(start)
        end=self.convert_datetime_to_tz(end)

        url=self.base
        setup=f"/electricity-meter-points/{self.mpan}/meters/{self.serial_number}/consumption/"
        
        parameters=f"?page_size=10000&period_from={start}&period_to={end}&order_by=period"

        url=f"{self.base}{setup}{parameters}"

        response = self._get(url)

        return(response['results'])



from octopus_energy_api import oe_api
import datetime

# Controller declarations
api = oe_api(api_key, mpan, serial_number, account_number)

# print(api.GetAccountDetails())

today = datetime.date.today()
start = today.replace(day=1)

print(api.get_consumption(start, today))






"""
data = database()

# Get last updated time for spreadsheet
last_updated = data.get_highest_interval_start()
last_updated = last_updated + datetime.timedelta(minutes = 30)
last_updated = data.convert_datetime(last_updated, output_type='tz')

# Call OE API to get all updates since then
end_time = data.convert_datetime(datetime.datetime.now(), output_type='tz')
output = api.get_consumption(last_updated, end_time)

# Upload data
if len(output)==0:
    print("no new data")

for row in output:
    print(f"{row['interval_start']} uploaded")
    new_row = []

    new_row.append(data.convert_datetime(row['interval_start'], input_type='tz', output_type='sheets'))
    new_row.append(data.convert_datetime(row['interval_end'], input_type='tz', output_type='sheets'))
    new_row.append(row['consumption'])
    
    start_day=data.convert_datetime(row['interval_start'], input_type='tz').strftime('%A')
    new_row.append(start_day)

    data.upload_row(new_row)
    time.sleep(2)"""
